| Title: | facets R wrapper |
|---|---|
| Description: | The goal of facetsr is to create an R wrapper for facets. So use facets to explore your dataset. |
| Authors: | c(person('Adam', 'Forys', email = '[email protected]', role = c('cre', 'aut'))) |
| Maintainer: | The package maintainer <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-06-04 09:01:27 UTC |
| Source: | https://github.com/openpharma/facetsr |
This function generate htmlwidget object that using facets from Google Pair
facets( data = list(), type = c("facets-dive", "facets-overview"), width = NULL, height = 600, elementId = NULL ) facets_dive(...) facets_overview(...)facets( data = list(), type = c("facets-dive", "facets-overview"), width = NULL, height = 600, elementId = NULL ) facets_dive(...) facets_overview(...)
data |
put data depends from facets type - facets-dive - data frame (multi table is not supported yet) - facets-overview - data frame or list of data frame as list of list |
type |
one of the type of facets c("facets-dive", "facets-overview") |
width |
width for html widget |
height |
height for html widget by default 600 |
elementId |
id of the element |
... |
arguments to facets wihout type |
the htmlwidget
# Use predefined function or standard facets # facets dive facets_dive(iris) # facets overview facets_overview(iris) facets_overview(list(list(data = iris, name = "iris"), list(data = cars, name = "cars"))) inst/examples/app.R# Use predefined function or standard facets # facets dive facets_dive(iris) # facets overview facets_overview(iris) facets_overview(list(list(data = iris, name = "iris"), list(data = cars, name = "cars"))) inst/examples/app.R
Output and render functions for using facets within Shiny applications and interactive Rmd documents.
facets_output(outputId, width = "100%", height = "auto") render_facets(expr, env = parent.frame(), quoted = FALSE)facets_output(outputId, width = "100%", height = "auto") render_facets(expr, env = parent.frame(), quoted = FALSE)
outputId |
output variable to read from |
width, height
|
Must be a valid CSS unit (like |
expr |
An expression that generates a facets canvas |
env |
The environment in which to evaluate |
quoted |
Is |
Access files in the current app
inst_path(...)inst_path(...)
... |
Character vector specifying directory and or file to point to inside the current package. |
## Not run: inst_path("") ## End(Not run)## Not run: inst_path("") ## End(Not run)